from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from tbc_video_export.config.json import JsonConfig

DEFAULT_CONFIG: JsonConfig = {
    "profiles": [
        {
            "name": "ffv1_10bit",
            "type": None,
            "default": True,
            "video_profile": "FFV1",
            "video_format": "yuv422p10le",
            "audio_profile": "FLAC",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_10bit_pcm",
            "type": None,
            "default": None,
            "video_profile": "FFV1",
            "video_format": "yuv422p10le",
            "audio_profile": "PCM",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_8bit",
            "type": None,
            "default": None,
            "video_profile": "FFV1",
            "video_format": "yuv422p",
            "audio_profile": "FLAC",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_8bit_pcm",
            "type": None,
            "default": None,
            "video_profile": "FFV1",
            "video_format": "yuv422p",
            "audio_profile": "PCM",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_444",
            "type": None,
            "default": None,
            "video_profile": "FFV1",
            "video_format": "yuv444p",
            "audio_profile": "FLAC",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_444_pcm",
            "type": None,
            "default": None,
            "video_profile": "FFV1",
            "video_format": "yuv444p",
            "audio_profile": "PCM",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_luma",
            "type": "luma",
            "default": True,
            "video_profile": "FFV1",
            "video_format": "y8",
            "audio_profile": "FLAC",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_luma_pcm",
            "type": "luma",
            "default": None,
            "video_profile": "FFV1",
            "video_format": "y8",
            "audio_profile": "PCM",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_luma_no_audio",
            "type": "luma",
            "default": None,
            "video_profile": "FFV1",
            "video_format": "y8",
            "audio_profile": None,
            "filter_profiles": [],
        },
        {
            "name": "prores_hq",
            "type": None,
            "default": None,
            "video_profile": "ProRes 422 HQ",
            "video_format": "yuv422p10le",
            "audio_profile": "PCM",
            "filter_profiles": [],
        },
        {
            "name": "prores_4444xq",
            "type": None,
            "default": None,
            "video_profile": "ProRes 4444 XQ",
            "video_format": "yuv444p10le",
            "audio_profile": "PCM",
            "filter_profiles": [],
        },
        {
            "name": "v210",
            "type": None,
            "default": None,
            "video_profile": "V210",
            "video_format": "yuv422p10le",
            "audio_profile": "PCM",
            "filter_profiles": [],
        },
        {
            "name": "v410",
            "type": None,
            "default": None,
            "video_profile": "V410",
            "video_format": "yuv422p10le",
            "audio_profile": "PCM",
            "filter_profiles": [],
        },
        {
            "name": "x264_web",
            "type": None,
            "default": None,
            "video_profile": "x264 web",
            "video_format": "yuv420p",
            "audio_profile": "AAC",
            "filter_profiles": ["BWDIF", "Colorlevels"],
        },
        {
            "name": "x264_lossless",
            "type": None,
            "default": None,
            "video_profile": "x264 lossless",
            "video_format": "yuv422p10le",
            "audio_profile": "FLAC",
            "filter_profiles": [],
        },
        {
            "name": "x264_lossless_8bit",
            "type": None,
            "default": None,
            "video_profile": "x264 lossless",
            "video_format": "yuv422p",
            "audio_profile": "FLAC",
            "filter_profiles": [],
        },
        {
            "name": "x265_web",
            "type": None,
            "default": None,
            "video_profile": "x265 web",
            "video_format": "yuv420p",
            "audio_profile": "AAC",
            "filter_profiles": ["BWDIF", "Colorlevels"],
        },
        {
            "name": "x265_lossless",
            "type": None,
            "default": None,
            "video_profile": "x265 lossless",
            "video_format": "yuv422p10le",
            "audio_profile": "FLAC",
            "filter_profiles": [],
        },
        {
            "name": "x265_lossless_8bit",
            "type": None,
            "default": None,
            "video_profile": "x265 lossless",
            "video_format": "yuv422p",
            "audio_profile": "FLAC",
            "filter_profiles": [],
        },
    ],
    "video_profiles": [
        {
            "name": "FFV1",
            "codec": "ffv1",
            "container": "mkv",
            "opts": [
                "-coder",
                1,
                "-level",
                3,
                "-context",
                1,
                "-slices",
                24,
                "-slicecrc",
                1,
                "-g",
                1,
            ],
        },
        {
            "name": "ProRes 422 HQ",
            "codec": "prores",
            "container": "mov",
            "opts": [
                "-profile:v",
                3,
                "-vendor",
                "apl0",
                "-bits_per_mb",
                8000,
                "-quant_mat",
                "hq",
                "-mbs_per_slice",
                8,
            ],
        },
        {
            "name": "ProRes 4444 XQ",
            "codec": "prores",
            "container": "mov",
            "opts": [
                "-profile:v",
                5,
                "-vendor",
                "apl0",
                "-bits_per_mb",
                8000,
                "-quant_mat",
                "hq",
                "-mbs_per_slice",
                8,
            ],
        },
        {"name": "V210", "codec": "v210", "container": "mov", "opts": None},
        {"name": "V410", "codec": "v410", "container": "mov", "opts": None},
        {
            "name": "x264 web",
            "codec": "libx264",
            "container": "mov",
            "opts": [
                "-crf",
                18,
                "-preset",
                "slow",
                "-maxrate",
                "8M",
                "-bufsize",
                "16M",
                "-movflags",
                "+faststart",
                "-x264opts",
                "interlaced=0",
            ],
        },
        {
            "name": "x264 lossless",
            "codec": "libx264",
            "container": "mov",
            "opts": ["-qp", 0, "-preset", "veryslow"],
        },
        {
            "name": "x265 web",
            "codec": "libx265",
            "container": "mov",
            "opts": [
                "-crf",
                20,
                "-preset",
                "slow",
                "-maxrate",
                "8M",
                "-bufsize",
                "16M",
                "-movflags",
                "+faststart",
                "-x265-params",
                "interlace=false",
            ],
        },
        {
            "name": "x265 lossless",
            "codec": "libx265",
            "container": "mov",
            "opts": [
                "-preset",
                "veryslow",
                "-movflags",
                "+faststart",
                "-x265-params",
                "lossless=1",
            ],
        },
    ],
    "audio_profiles": [
        {"name": "FLAC", "codec": "flac", "opts": ["-compression_level", 12]},
        {"name": "PCM", "codec": "pcm_s24le", "opts": None},
        {"name": "AAC", "codec": "aac", "opts": ["-ar", 48000, "-b:a", "320K"]},
    ],
    "filter_profiles": [
        {
            "name": "BWDIF",
            "video_filter": "bwdif",
            "other_filter": None,
        },
        {
            "name": "Colorlevels",
            "video_filter": "colorlevels=rimin=32/255:gimin=32/255:bimin=32/255",
            "other_filter": None,
        },
        {
            "name": "Map L to L+R",
            "video_filter": None,
            "other_filter": "[2:a]pan=stereo|FL=FL|FR=FL",
        },
    ],
}
